from .date_calculation import meesters_dunai, iterated_date, get_date
from .linear_propagation import date_uncertainty, date_uncertainty_with235
from .montecarlo import monte_carlo
from .main import hecalc_main

# Numerical version:
__version_info__ = (1, 0, 1)
__version__ = '.'.join(map(str, __version_info__))

__author__ = 'Peter E. Martin <peter.martin-2@colorado.edu>'
